@@ -39,10 +39,13 @@ class ExtraTreesAlgorithm(SklearnTreesEnsembleClassifierAlgorithm):
             max_features=params.get("max_features", 0.8),
             max_depth=params.get("max_depth", 6),
             min_samples_split=params.get("min_samples_split", 4),
+            min_samples_leaf=params.get("min_samples_leaf", 1),
             warm_start=True,
             n_jobs=params.get("n_jobs", -1),
             random_state=params.get("seed", 1),
         )
+        if "max_steps" in params:
+            self.max_steps = params["max_steps"]
 
     def file_extension(self):
         return "extra_trees"
@@ -72,6 +75,7 @@ class ExtraTreesRegressorAlgorithm(SklearnTreesEnsembleRegressorAlgorithm):
             max_features=params.get("max_features", 0.6),
             max_depth=params.get("max_depth", 6),
             min_samples_split=params.get("min_samples_split", 30),
+            min_samples_leaf=params.get("min_samples_leaf", 1),
             warm_start=True,
             n_jobs=params.get("n_jobs", -1),
             random_state=params.get("seed", 1),
