@@ -31,6 +31,11 @@ logger.setLevel(LOG_LEVEL)
 from supervised.utils.config import mem
 from supervised.utils.learning_curves import LearningCurves
 
+import optuna
+import joblib
+
+from supervised.tuner.optuna.tuner import OptunaTuner
+
 
 class ModelFramework:
     def __init__(self, params, callbacks=[]):
@@ -69,6 +74,8 @@ class ModelFramework:
         self._max_time_for_learner = params.get("max_time_for_learner", 3600)
         self._oof_predictions_fname = None
         self._single_prediction_time = None  # prediction time on single sample
+        self._optuna_time_budget = params.get("optuna_time_budget")
+        self._optuna_init_params = params.get("optuna_init_params", {})
 
     def get_train_time(self):
         return self.train_time
@@ -120,6 +127,21 @@ class ModelFramework:
         start_time = time.time()
         np.random.seed(self.learner_params["seed"])
 
+        optuna_tuner = None
+        if self._optuna_time_budget is not None and OptunaTuner.is_optimizable(
+            self.learner_params.get("model_type", "")
+        ):
+            optuna_tuner = OptunaTuner(
+                results_path,
+                ml_task=self._ml_task,
+                eval_metric=self.get_metric(),
+                time_budget=self._optuna_time_budget,
+                init_params=self._optuna_init_params,
+                verbose=True,#False,
+                n_jobs=self.learner_params.get("n_jobs", -1),
+                random_state=self.learner_params.get("seed", 42),
+            )
+
         self.validation = ValidationStep(self.validation_params)
 
         repeats = self.validation.get_repeats()
@@ -159,6 +181,19 @@ class ModelFramework:
                     validation_data.get("sample_weight"),
                 )
 
+                if optuna_tuner is not None:
+                    self.learner_params = optuna_tuner.optimize(
+                        self.learner_params.get("model_type", ""),
+                        self.params.get("data_type", ""),
+                        X_train,
+                        y_train,
+                        sample_weight,
+                        X_validation,
+                        y_validation,
+                        sample_weight_validation,
+                        self.learner_params,
+                    )
+
                 self.learner_params["explain_level"] = self._explain_level
                 self.learners += [
                     AlgorithmFactory.get_algorithm(copy.deepcopy(self.learner_params))
