@@ -41,6 +41,8 @@ class MljarTuner:
         boost_on_errors,
         kmeans_features,
         mix_encoding,
+        optuna_time_budget,
+        optuna_init_params,
         n_jobs,
         seed,
     ):
@@ -61,6 +63,8 @@ class MljarTuner:
         self._boost_on_errors = boost_on_errors
         self._kmeans_features = kmeans_features
         self._mix_encoding = mix_encoding
+        self._optuna_time_budget = optuna_time_budget
+        self._optuna_init_params = optuna_init_params
         self._n_jobs = n_jobs
         self._seed = seed
         self._unique_params_keys = []
@@ -287,6 +291,10 @@ class MljarTuner:
             params["status"] = "initialized"
             params["final_loss"] = None
             params["train_time"] = None
+            params["data_type"] += "_stacked"
+            if self._optuna_time_budget is not None:
+                params["optuna_time_budget"] = self._optuna_time_budget
+                params["optuna_init_params"] = self._optuna_init_params
 
             if "model_architecture_json" in params["learner"]:
                 # the new model will be created with wider input size
@@ -333,6 +341,7 @@ class MljarTuner:
             params["status"] = "initialized"
             params["final_loss"] = None
             params["train_time"] = None
+            params["data_type"] = "original"
 
             unique_params_key = MljarTuner.get_params_key(params)
             if unique_params_key not in self._unique_params_keys:
@@ -358,6 +367,7 @@ class MljarTuner:
                 params["status"] = "initialized"
                 params["final_loss"] = None
                 params["train_time"] = None
+                params["data_type"] = "original"
 
                 unique_params_key = MljarTuner.get_params_key(params)
                 if unique_params_key not in self._unique_params_keys:
@@ -407,12 +417,17 @@ class MljarTuner:
             )
             if params is None:
                 continue
+            special = "Default_" if self._optuna_time_budget is None else "Optuna_"
             params["name"] = self.get_model_name(
-                model_type, models_cnt + 1, special="Default_"
+                model_type, models_cnt + 1, special=special
             )
             params["status"] = "initialized"
             params["final_loss"] = None
             params["train_time"] = None
+            params["data_type"] = "original"
+            if self._optuna_time_budget is not None:
+                params["optuna_time_budget"] = self._optuna_time_budget
+                params["optuna_init_params"] = self._optuna_init_params
 
             unique_params_key = MljarTuner.get_params_key(params)
             if unique_params_key not in self._unique_params_keys:
@@ -454,6 +469,10 @@ class MljarTuner:
                 params["status"] = "initialized"
                 params["final_loss"] = None
                 params["train_time"] = None
+                params["data_type"] = "original"
+                if self._optuna_time_budget is not None:
+                    params["optuna_time_budget"] = self._optuna_time_budget
+                    params["optuna_init_params"] = self._optuna_init_params
 
                 unique_params_key = MljarTuner.get_params_key(params)
                 if unique_params_key not in self._unique_params_keys:
@@ -579,7 +598,7 @@ class MljarTuner:
             # try to add categorical strategy only for below algorithms
             if m_type not in [
                 "Xgboost",
-                "LightGBM",
+                # "LightGBM", # use built-in categoricals (but need to int encode)
                 # "Neural Network",
                 # "Random Forest",
                 # "Extra Trees",
@@ -640,6 +659,11 @@ class MljarTuner:
                 params["status"] = "initialized"
                 params["final_loss"] = None
                 params["train_time"] = None
+                params["data_type"] = params.get("data_type", "") + "_" + strategy
+                if self._optuna_time_budget is not None:
+                    params["optuna_time_budget"] = self._optuna_time_budget
+                    params["optuna_init_params"] = self._optuna_init_params
+
                 if "model_architecture_json" in params["learner"]:
                     del params["learner"]["model_architecture_json"]
                 unique_params_key = MljarTuner.get_params_key(params)
@@ -701,6 +725,10 @@ class MljarTuner:
             params["status"] = "initialized"
             params["final_loss"] = None
             params["train_time"] = None
+            params["data_type"] = params.get("data_type", "") + "_golden_features"
+            if self._optuna_time_budget is not None:
+                params["optuna_time_budget"] = self._optuna_time_budget
+                params["optuna_init_params"] = self._optuna_init_params
 
             if "model_architecture_json" in params["learner"]:
                 del params["learner"]["model_architecture_json"]
@@ -727,6 +755,10 @@ class MljarTuner:
             params["status"] = "initialized"
             params["final_loss"] = None
             params["train_time"] = None
+            params["data_type"] = params.get("data_type", "") + "_kmeans_features"
+            if self._optuna_time_budget is not None:
+                params["optuna_time_budget"] = self._optuna_time_budget
+                params["optuna_init_params"] = self._optuna_init_params
 
             if "model_architecture_json" in params["learner"]:
                 del params["learner"]["model_architecture_json"]
@@ -798,6 +830,11 @@ class MljarTuner:
         params["explain_level"] = 1
         if "model_architecture_json" in params["learner"]:
             del params["learner"]["model_architecture_json"]
+        if self._optuna_time_budget is not None:
+            # dont tune algorithm with random feature inserted
+            # algorithm will be tuned after feature selection
+            params["optuna_time_budget"] = None
+            params["optuna_init_params"] = {}
 
         unique_params_key = MljarTuner.get_params_key(params)
         if unique_params_key not in self._unique_params_keys:
@@ -847,6 +884,13 @@ class MljarTuner:
                 params["status"] = "initialized"
                 params["final_loss"] = None
                 params["train_time"] = None
+                params["data_type"] = (
+                    params.get("data_type", "") + "_features_selection"
+                )
+                if self._optuna_time_budget is not None:
+                    params["optuna_time_budget"] = self._optuna_time_budget
+                    params["optuna_init_params"] = self._optuna_init_params
+
                 if "model_architecture_json" in params["learner"]:
                     del params["learner"]["model_architecture_json"]
                 unique_params_key = MljarTuner.get_params_key(params)
@@ -971,8 +1015,12 @@ class MljarTuner:
         params["status"] = "initialized"
         params["final_loss"] = None
         params["train_time"] = None
+        params["data_type"] = "boost_on_error"
         if "model_architecture_json" in params["learner"]:
             del params["learner"]["model_architecture_json"]
+        if self._optuna_time_budget is not None:
+            params["optuna_time_budget"] = self._optuna_time_budget
+            params["optuna_init_params"] = self._optuna_init_params
         unique_params_key = MljarTuner.get_params_key(params)
 
         if unique_params_key not in self._unique_params_keys:
